************************************************************************************************

*** Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*** Journal of Family Research, 2023
*** Title: 05_JFR_Descriptive_Analysis_Baseline_DEAS
*** Author: Luisa Bischoff

*** Data set: DEAS
* 1996: SUF_DEAS1996_3-0_de_Stata, doi: 10.5156/DEAS.1996.M.004
* 2002: SUF_DEAS2002_3-1_de_Stata, doi: 10.5156/DEAS.2002.M.005
* 2008: SUF_DEAS2008_3-1_de_Stata, doi: 10.5156/DEAS.2008.M.005
* 2011: SUF_DEAS_2011_2-1_de_Stata, doi: 10.5156/DEAS.2011.M.004
* 2014: SUF_DEAS_2014_3-0_de, doi: 10.5156/DEAS.2014.M.005
* 2017: SUF_DEAS_2017_2-0_de, doi: 10.5156/DEAS.2017.M.003
* Meta: SUF_DEAS_Meta_05_2020_de

************************************************************************************************
************************************************************************************************

clear all
capture log close
version 16.1
set more off

*Directories
global inpath 	//	directory of original data
global outpath 	//  working directory
cd $inpath	

************************************************************************************************

use SUF_DEAS1996_3-0_de_Stata.dta, clear

************************************************************************************************
*** Dependent variables
rename d4_20 freedom
rename d4_13 needs
rename d4_19 adaption
rename d1_30 cognitive
rename d4_40 dependency
rename d4_46 vitality
rename d4_48 serenity

* Recoding negatively formulated perceptions
recode adaption dependency vitality (1=0) (2=1) (3=2) (4=3)

label define PERCEPTIONNEG 0 "Strongly agree" 1 "Agree" 2 "Disagree" 3 "Strongly disagree" 

foreach X of varlist adaption dependency vitality {
	label values `X' PERCEPTIONNEG
}

label variable adaption "Perception of ageing: Adaption"
label variable dependency "Perception of ageing: Dependency"
label variable vitality "Perception of ageing: Vitality"

* Recoding positively formulated perceptions
recode freedom needs cognitive serenity (4=0) (3=1) (2=2) (1=3) 

label define PERCEPTIONPOS 0 "Strongly disagree" 1 "Disagree" 2 "Agree" 3 "Strongly agree" 

foreach X of varlist freedom needs cognitive serenity {
	label values `X' PERCEPTIONPOS
}

label variable freedom "Perception of ageing: Freedom"
label variable needs "Perception of ageing: Needs"
label variable cognitive "Perception of ageing: Cognitive capacity"
label variable serenity "Perception of ageing: Serenity"

* Generating index 
egen pa = rowmean(freedom needs adaption serenity cognitive dependency vitality)
label variable pa "Perceptions of aging (index)"

************************************************************************************************
*** Independent variables
* Age when interviewed
rename altervoll_96 age
label variable age "Age"

* Grandparenthood
gen grandparents = .c
replace grandparents=0 if anzenk_96==0
replace grandparents=1 if anzenk_96!=0

label define GRANDPARENTS 0 "No" 1 "Yes" 
label variable grandparents "Grandparenthood"
label values grandparents GRANDPARENTS

* Network size
rename nwgroesse_96 network

* Physical health
generate health = .
replace health = anzphy_96 if (anzphy_96 != .f) & (anzphy_96 != .) 
label variable health "Physical health"

* Marital status
generate marital = .c
replace marital = 1 if v9_11==1
replace marital = 2 if v9_14==1
replace marital = 3 if v9_19==1
replace marital = 4 if v9_24==1
replace marital = 5 if v9_29==1 
replace marital = .c if v9_11==0 & v9_14==0 & v9_19==0 & v9_24==0 & v9_29==0

label define MARITAL 1 "married, living together" 2 "married, living separate" 3 "divorced" 4 "widowed"
label variable marital "Marital status"
label values marital MARITAL

* Relationship status 
generate relstatus = v9_30
replace relstatus = 1 if v9_35==1
replace relstatus = 2 if v9_35==2

label define RELSTATUS 1 "Yes" 2 "No" 
label variable relstatus "Living in a nonmarital relationship"
label values relstatus RELSTATUS

* Combination of marital and relationship status
generate relationship = .c 
replace relationship = 1 if marital==1 
replace relationship = 2 if (marital==2) & (relstatus==2) 
replace relationship = 3 if (marital==3) & (relstatus==2) 
replace relationship = 4 if (marital==4) & (relstatus==2) 
replace relationship = 5 if (marital==5) & (relstatus==2) 
replace relationship = 6 if (marital==2) & (relstatus==1) 
replace relationship = 7 if (marital==3) & (relstatus==1) 
replace relationship = 8 if (marital==4) & (relstatus==1) 
replace relationship = 9 if (marital==5) & (relstatus==1) 

label define RELATIONSHIP 1 " married, living together" 2 "married, living separate, single" 3 "divorced, single" 4 "widowed, single" 5 " never married, single" 6 "married, living separate, partnered" 7 "divorced, partnered" 8 "widowed, partnered" 9 "never married, partnered" 
label variable relationship "Combined relationship and marital status"
label values relationship RELATIONSHIP

* Age at transition
generate yob= 1996-age

* Widowhood
generate yow = v9_25 + 1900 if marital==4
generate ageWID = yow-yob

* Divorce/ Separation
generate yos = v11_28 + 1900 if marital==2
replace yos = v9_20 + 1900 if marital==3
replace yos = v11_28 + 1900 if relstatus==2
generate ageDIV = yos-yob

* Marriage
generate yom = v9_12 + 1900 if marital==1
replace yom = v9_38 + 1900 if relstatus==1
generate ageRP = yom-yob

replace ageWID = .c if ageWID<=14
replace ageDIV = .c if ageDIV<=14
replace ageRP = .c if ageRP<=14

drop yob

save SUF_DEAS1996_3-0_de_Stata_crossectional_JFR.dta, replace

************************************************************************************************
************************************************************************************************
use SUF_DEAS2002_3-1_de_Stata.dta, clear

drop if part_96==1
// Exclude panel respondents

*** Dependent variables
rename e1_1 freedom
rename e1_11 needs
rename e14_4 adaption
rename e14_6 cognitive
rename e14_10 dependency
rename e14_14 vitality
rename e14_15 serenity

* Recoding negatively formulated perceptions
recode adaption dependency vitality (1=0) (2=1) (3=2) (4=3)

label define PERCEPTIONNEG 0 "Strongly agree" 1 "Agree" 2 "Disagree" 3 "Strongly disagree" 

foreach X of varlist adaption dependency vitality {
	label values `X' PERCEPTIONNEG
}

label variable adaption "Perception of ageing: Adaption"
label variable dependency "Perception of ageing: Dependency"
label variable vitality "Perception of ageing: Vitality"

* Recoding positively formulated perceptions
recode freedom needs cognitive serenity (4=0) (3=1) (2=2) (1=3) 

label define PERCEPTIONPOS 0 "Strongly disagree" 1 "Disagree" 2 "Agree" 3 "Strongly agree" 

foreach X of varlist freedom needs cognitive serenity {
	label values `X' PERCEPTIONPOS
}

label variable freedom "Perception of ageing: Freedom"
label variable needs "Perception of ageing: Needs"
label variable cognitive "Perception of ageing: Cognitive capacity"
label variable serenity "Perception of ageing: Serenity"

* Generating index 
egen pa = rowmean(freedom needs adaption serenity cognitive dependency vitality)
label variable pa "Perceptions of aging (index)"

* Age when interviewed
rename altervoll_02 age
label variable age "Age"

* Grandparenthood
gen grandparents = .c
replace grandparents=0 if anzenk_02==0
replace grandparents=1 if anzenk_02!=0

label define GRANDPARENTS 0 "No" 1 "Yes" 
label variable grandparents "Grandparenthood"
label values grandparents GRANDPARENTS

* Network size
rename nwgroesse_02 network

* Physical health
generate health = .
replace health = anzphy_02 if (anzphy_02 != .c) & (anzphy_02 != .f) & (anzphy_02 != .) 
label variable health "Physical health"

* Marital status
rename w18_11 marital

label define MARITAL 1 "married, living together" 2 "married, living separate" 3 "divorced" 4 "widowed"
label variable marital "Marital status"
label values marital MARITAL

* Relationship status 
generate relstatus = w18_40
replace relstatus = 1 if w18_45==1
replace relstatus = 2 if w18_45==2

label define RELSTATUS 1 "Yes" 2 "No" 
label variable relstatus "Living in a nonmarital relationship"
label values relstatus RELSTATUS

* Combination of marital and relationship status
generate relationship = .c 
replace relationship = 1 if marital==1 
replace relationship = 2 if (marital==2) & (relstatus==2) 
replace relationship = 3 if (marital==3) & (relstatus==2) 
replace relationship = 4 if (marital==4) & (relstatus==2) 
replace relationship = 5 if (marital==5) & (relstatus==2) 
replace relationship = 6 if (marital==2) & (relstatus==1) 
replace relationship = 7 if (marital==3) & (relstatus==1) 
replace relationship = 8 if (marital==4) & (relstatus==1) 
replace relationship = 9 if (marital==5) & (relstatus==1) 

label define RELATIONSHIP 1 " married, living together" 2 "married, living separate, single" 3 "divorced, single" 4 "widowed, single" 5 " never married, single" 6 "married, living separate, partnered" 7 "divorced, partnered" 8 "widowed, partnered" 9 "never married, partnered" 
label variable relationship "Combined relationship and marital status"
label values relationship RELATIONSHIP

* Age at transition
generate yob=2002-age

* Widowhood
generate yow = w18_32 if marital==4
generate ageWID = yow-yob

* Divorce/ Separation
generate yos = w18_16 if marital==2
replace yos = w18_24 if marital==3
replace yos = w18_16 if relstatus==2
replace yos = w18_1354 if yos==.c
generate ageDIV = yos-yob

* Marriage
generate yom = w18_12 if marital==1
replace yom = w18_48 if relstatus==1
generate ageRP = yom-yob

replace ageWID = .c if ageWID<=14
replace ageDIV = .c if ageDIV<=14
replace ageRP = .c if ageRP<=14

drop yob

save SUF_DEAS2002_3-1_de_Stata_crossectional_JFR.dta, replace

************************************************************************************************
************************************************************************************************
use SUF_DEAS2008_3-1_de_Stata.dta, clear

drop if part_96==1
drop if part_02==1
// Exclude panel respondents

*** Dependent variables
rename f1_1 freedom
rename f1_6 needs
rename f16_3 adaption
rename f16_5 cognitive
rename f16_7 dependency
rename f16_9 vitality
rename f16_10 serenity

* Recoding negatively formulated perceptions
recode adaption dependency vitality (1=0) (2=1) (3=2) (4=3)

label define PERCEPTIONNEG 0 "Strongly agree" 1 "Agree" 2 "Disagree" 3 "Strongly disagree" 

foreach X of varlist adaption dependency vitality {
	label values `X' PERCEPTIONNEG
}

label variable adaption "Perception of ageing: Adaption"
label variable dependency "Perception of ageing: Dependency"
label variable vitality "Perception of ageing: Vitality"

* Recoding positively formulated perceptions
recode freedom needs cognitive serenity (4=0) (3=1) (2=2) (1=3) 

label define PERCEPTIONPOS 0 "Strongly disagree" 1 "Disagree" 2 "Agree" 3 "Strongly agree" 

foreach X of varlist freedom needs cognitive serenity {
	label values `X' PERCEPTIONPOS
}

label variable freedom "Perception of ageing: Freedom"
label variable needs "Perception of ageing: Needs"
label variable cognitive "Perception of ageing: Cognitive capacity"
label variable serenity "Perception of ageing: Serenity"

* Generating index 
egen pa = rowmean(freedom needs adaption serenity cognitive dependency vitality)
label variable pa "Perceptions of aging (index)"

* Age when interviewed
rename altervoll_08 age
label variable age "Age"

* Grandparenthood
gen grandparents = .c
replace grandparents=0 if anzenk_08==0
replace grandparents=1 if anzenk_08!=0

label define GRANDPARENTS 0 "No" 1 "Yes" 
label variable grandparents "Grandparenthood"
label values grandparents GRANDPARENTS

* Network size
rename nwgroesse_08 network

* Physical health
generate health = .
replace health = anzphy_08 if (anzphy_08 != .f) & (anzphy_08 != .) 
label variable health "Physical health"

* Marital status
rename x200 marital

label define MARITAL 1 "married, living together" 2 "married, living separate" 3 "divorced" 4 "widowed"
label variable marital "Marital status"
label values marital MARITAL

* Relationship status 
generate relstatus = .c
replace relstatus = 1 if x200o==1
replace relstatus = 2 if x200o==2
replace relstatus = 1 if x202==1
replace relstatus = 2 if x202==2

label define RELSTATUS 1 "Yes" 2 "No" 
label variable relstatus "Living in a nonmarital relationship"
label values relstatus RELSTATUS

* Combination of marital and relationship status
generate relationship = .c 
replace relationship = 1 if marital==1 
replace relationship = 2 if (marital==2) & (relstatus==2) 
replace relationship = 3 if (marital==3) & (relstatus==2) 
replace relationship = 4 if (marital==4) & (relstatus==2) 
replace relationship = 5 if (marital==5) & (relstatus==2) 
replace relationship = 6 if (marital==2) & (relstatus==1) 
replace relationship = 7 if (marital==3) & (relstatus==1) 
replace relationship = 8 if (marital==4) & (relstatus==1) 
replace relationship = 9 if (marital==5) & (relstatus==1) 

label define RELATIONSHIP 1 " married, living together" 2 "married, living separate, single" 3 "divorced, single" 4 "widowed, single" 5 " never married, single" 6 "married, living separate, partnered" 7 "divorced, partnered" 8 "widowed, partnered" 9 "never married, partnered" 
label variable relationship "Combined relationship and marital status"
label values relationship RELATIONSHIP

* Age at transition
generate yob = 2008-age

* Widowhood
generate yow = x200j_2 if marital==4
generate ageWID = yow-yob

* Divorce/ Separation
generate yos = x200d_2 if marital==2
replace yos = x200g_2 if marital==3
replace yos = x200d_2 if relstatus==2
replace yos = x237_2 if (yos==.a) | (yos==.b) | (yos==.d)
generate ageDIV = yos-yob

* Marriage
generate yom = x200a_2 if marital==1
replace yom = x203b_2 if relstatus==1
generate ageRP = yom-yob

replace ageWID = .c if ageWID<=14
replace ageDIV = .c if ageDIV<=14
replace ageRP = .c if ageRP<=14

drop yob


save SUF_DEAS2008_3-1_de_Stata_crossectional_JFR.dta, replace

************************************************************************************************
************************************************************************************************
use SUF_DEAS_2014_3-0_de.dta, clear

drop if part_96==1
drop if part_02==1
drop if part_08==1
// Exclude panel respondents

*** Dependent variables
rename hd1_1 freedom
rename hd1_6 needs
rename hd17_3 adaption
rename hd17_5 cognitive
rename hd17_7 dependency
rename hd17_9 vitality
rename hd17_10 serenity

* Recoding negatively formulated perceptions
recode adaption dependency vitality (1=0) (2=1) (3=2) (4=3)

label define PERCEPTIONNEG 0 "Strongly agree" 1 "Agree" 2 "Disagree" 3 "Strongly disagree" 

foreach X of varlist adaption dependency vitality {
	label values `X' PERCEPTIONNEG
}

label variable adaption "Perception of ageing: Adaption"
label variable dependency "Perception of ageing: Dependency"
label variable vitality "Perception of ageing: Vitality"

* Recoding positively formulated perceptions
recode freedom needs cognitive serenity (4=0) (3=1) (2=2) (1=3) 

label define PERCEPTIONPOS 0 "Strongly disagree" 1 "Disagree" 2 "Agree" 3 "Strongly agree" 

foreach X of varlist freedom needs cognitive serenity {
	label values `X' PERCEPTIONPOS
}

label variable freedom "Perception of ageing: Freedom"
label variable needs "Perception of ageing: Needs"
label variable cognitive "Perception of ageing: Cognitive capacity"
label variable serenity "Perception of ageing: Serenity"

* Generating index 
egen pa = rowmean(freedom needs adaption serenity cognitive dependency vitality)
label variable pa "Perceptions of aging (index)"

* Age when interviewed
rename altervoll_14 age
label variable age "Age"

* Grandparenthood
gen grandparents = .c
replace grandparents=0 if anzenk_14==0
replace grandparents=1 if anzenk_14!=0

label define GRANDPARENTS 0 "No" 1 "Yes"  
label variable grandparents "Grandparenthood"
label values grandparents GRANDPARENTS

* Network size
rename nwgroesse_14 network

* Physical health
generate health = .
replace health = anzphy_14 if (anzphy_14 != .e) & (anzphy_14 != .f) & (anzphy_14 != .g) & (anzphy_14 != .) 
label variable health "Physical health"

* Marital status
generate marital = .c
replace marital = 1 if famstand_14==1
replace marital = 2 if famstand_14==2
replace marital = 3 if famstand_14==3
replace marital = 4 if famstand_14==4
replace marital = 5 if famstand_14==5
replace marital = 1 if fallnum==3001164

label define MARITAL 1 "married, living together" 2 "married, living separate" 3 "divorced" 4 "widowed"
label variable marital "Marital status"
label values marital MARITAL

* Relationship status 
generate relstatus = .c
replace relstatus = 1 if (partner_14==2) & (marital!=1)
replace relstatus = 1 if partner_14==3
replace relstatus = 2 if partner_14==1

label define RELSTATUS 1 "Yes" 2 "No" 
label variable relstatus "Living in a nonmarital relationship"
label values relstatus RELSTATUS
	
* Combination of marital and relationship status
generate relationship = .c 
replace relationship = 1 if marital==1 
replace relationship = 2 if (marital==2) & (relstatus==2) 
replace relationship = 3 if (marital==3) & (relstatus==2) 
replace relationship = 4 if (marital==4) & (relstatus==2) 
replace relationship = 5 if (marital==5) & (relstatus==2) 
replace relationship = 6 if (marital==2) & (relstatus==1) 
replace relationship = 7 if (marital==3) & (relstatus==1) 
replace relationship = 8 if (marital==4) & (relstatus==1) 
replace relationship = 9 if (marital==5) & (relstatus==1) 

label define RELATIONSHIP 1 " married, living together" 2 "married, living separate, single" 3 "divorced, single" 4 "widowed, single" 5 " never married, single" 6 "married, living separate, partnered" 7 "divorced, partnered" 8 "widowed, partnered" 9 "never married, partnered" 
label variable relationship "Combined relationship and marital status"
label values relationship RELATIONSHIP

* Age at transition
generate yob = 2014-age

* Widowhood
generate yow = hc252_y if marital==4
replace yow = hc282d_y if yow==.c
replace yow = hc252_y if yow==.c
replace yow = hc283m_y1 if (yow==.c) & (hc283k1==4)
replace yow = hc283m_y2 if (yow==.c) & (hc283k2==4)
generate ageWID = yow-yob

* Divorce/ Separation
generate yos = hc251_y if marital==2
replace yos = hc250_y if marital==3
replace yos = hc280ab if (yos==.a) | (yos==.b) | (yos==.c) | (yos==.g)
replace yos = hc282c_y if (yos==.a) | (yos==.b) | (yos==.c) | (yos==.g)
replace yos = hc283l_y1 if (yos==.a) | (yos==.b) | (yos==.c) | (yos==.g)
replace yos = hc283l_y2 if (yos==.a) | (yos==.b) | (yos==.c) | (yos==.g)
replace yos = hc251_y if relstatus==2
replace yos = hc273 if yos==.c
replace yos = hc282d_y if ((yos==.a) | (yos==.b) | (yos==.c)) & (hc282b==3)
replace yos = hc283m_y1 if ((yos==.a) | (yos==.b) | (yos==.c)) & (hc283k1==3)
replace yos = hc283m_y2 if ((yos==.a) | (yos==.b) | (yos==.c)) & (hc283k2==3)
generate ageDIV = yos-yob

* Marriage
generate yom = hc253_y if marital==1
replace yom = hc203_y if yom==.c
replace yom = hc283h_y1 if (hc283g1==1) & (yom==.c)
replace yom = hc204_y if relstatus==1
generate ageRP = yom-yob

replace ageWID = .c if ageWID<=14
replace ageDIV = .c if ageDIV<=14
replace ageRP = .c if ageRP<=14

drop yob

save SUF_DEAS_2014_3-0_de_crossectional_JFR.dta, replace

************************************************************************************************

* Opening wave 1
use SUF_DEAS1996_3-0_de_Stata_crossectional_JFR.dta, clear

* Adding wave 2
merge 1:1 fallnum using SUF_DEAS2002_3-1_de_Stata_crossectional_JFR.dta

* Adding wave 3
drop _merge
merge 1:1 fallnum using SUF_DEAS2008_3-1_de_Stata_crossectional_JFR.dta

* Adding wave 5
drop _merge
merge 1:1 fallnum using SUF_DEAS_2014_3-0_de_crossectional_JFR.dta

* Adding the meta data set
drop _merge
merge 1:1 fallnum using SUF_DEAS_Meta_05_2020_de.dta

save Baseline_crosssectional_JFR.dta, replace

* Gender
drop v1_11 w1_11 x1 hc1

recode gender (1=0) (2=1)

label define gender 0 "Men" 1 "Women" 
label variable gender "Gender"
label values gender gender


* Educational attainment
rename isced education
drop isced_96 isced_02 isced_08 isced_14

recode education (1=0) (2=1) (3=2)

label define education 0 "low (ISCED 0-2)" 1 "medium (ISCED 3-4)" 2 "high (ISCED 5-6)" 
label values education education


* Migration experience
rename migrat migrationshintergrund

generate migrat = .c
replace migrat = 0 if (v16_56==1) | (w25_11==1) | (x325==1) | (hc25a==1) | (migrationshintergrund==0)  
replace migrat = 1 if (v16_56==2) | (v16_56==3) | (v16_56==4) | (w25_11==2) | (w25_11==3) | (w25_11==4) | (x325==2) | (x325==3) | (x325==4) | (hc25a==2) | (hc25a==3) | (hc25a==4) 
replace migrat = 0 if (w25_12 < 1950) | (x326 < 1950) | (hc25b < 1950) 

label define MIGRATION 0 "No" 1 "Yes" 
label variable migrat "Migration experience"
label values migrat MIGRATION


************************************************************************************************
*** Description of the baseline sample 

* The following code was used to create Table A.1a
tab1 relationship gender education migrat grandparents
sum pa freedom needs adaption cognitive dependency vitality serenity age health network ageWID ageDIV ageRP n_obs


************************************************************************************************
************************************************************************************************
*** Preparation of the analysis sample 

cd $outpath
use preparation_DEAS.dta, clear

*** Widowhood 
* Relationship status

foreach X of numlist 1/6 {
	generate widowed`X' = .c
}

foreach X of numlist 1/6 {
	replace widowed`X' = 1 if (relationship`X'==4) 
	replace widowed`X' = 0 if (relationship`X'==1) 
}

label define WIDOWED 0 "Married, living together" 1 "Widowed, single" 

foreach X of varlist widowed1-widowed6 {
	label variable `X' "Widowed"
	label values `X' WIDOWED
}

* Transition to widowhood

foreach X of numlist 2/6 {
	generate widowhood`X' = .c	
}

* wave 1 to wave 2
replace widowhood2 = 0 if (widowed1==0) & (widowed2==0) 
replace widowhood2 = 0 if (widowed1==1) & (widowed2==0) 
replace widowhood2 = 0 if (widowed1==1) & (widowed2==1) 
replace widowhood2 = 1 if (widowed1==0) & (widowed2==1) 

* wave 2 to wave 3
replace widowhood3 = 0 if (widowed2==0) & (widowed3==0) 
replace widowhood3 = 0 if (widowed2==1) & (widowed3==0) 
replace widowhood3 = 0 if (widowed2==1) & (widowed3==1) 
replace widowhood3 = 1 if (widowed2==0) & (widowed3==1) 

* wave 3 to wave 4
replace widowhood4 = 0 if (widowed3==0) & (widowed4==0) 
replace widowhood4 = 0 if (widowed3==1) & (widowed4==0) 
replace widowhood4 = 0 if (widowed3==1) & (widowed4==1) 
replace widowhood4 = 1 if (widowed3==0) & (widowed4==1) 

* wave 4 to wave 5
replace widowhood5 = 0 if (widowed4==0) & (widowed5==0) 
replace widowhood5 = 0 if (widowed4==1) & (widowed5==0) 
replace widowhood5 = 0 if (widowed4==1) & (widowed5==1) 
replace widowhood5 = 1 if (widowed4==0) & (widowed5==1) 

* wave 5 to wave 6
replace widowhood6 = 0 if (widowed5==0) & (widowed6==0) 
replace widowhood6 = 0 if (widowed5==1) & (widowed6==0) 
replace widowhood6 = 0 if (widowed5==1) & (widowed6==1) 
replace widowhood6 = 1 if (widowed5==0) & (widowed6==1) 

* Summary
generate widowhood = 0 
replace widowhood = 1 if (widowhood2==1) | (widowhood3==1) | (widowhood4==1) | (widowhood5==1) | (widowhood6==1) 

label define widowhood 0 "widowhood does not occur" 1 "widowhood occurs" 

foreach X of varlist widowhood2-widowhood {
	label variable `X' "Transition to widowhood"
	label values `X' widowhood
}

************************************************************************************************
*** Divorce/ separation 
* Relationship status

foreach X of numlist 1/6 {
	generate divorced`X' = .c
}

foreach X of numlist 1/6 {
	replace divorced`X' = 1 if ((relationship`X'==2) | (relationship`X'==3)) & (widowhood!=1)  
	replace divorced`X' = 0 if (relationship`X'==1) & (widowhood!=1)
}

label define DIVORCED 0 "Married, living together" 1 "Divorced, single" 

foreach X of varlist divorced1-divorced6 {
	label variable `X' "Divorced"
	label values `X' DIVORCED
}


foreach X of numlist 1/6 {
	generate separated`X' = .c
}

foreach X of numlist 1/6 {
	replace separated`X' = 1 if ((relationship`X'==2) | (relationship`X'==3) | (relationship`X'==4)) & (widowhood!=1)  
	replace separated`X' = 0 if ((relationship`X'==5) | (relationship`X'==6) | (relationship`X'==7)) & (widowhood!=1) 
}

label define SEPARATED 0 "Partnered" 1 "Separated, single" 

foreach X of varlist separated1-separated6 {
	label variable `X' "Separated "
	label values `X' SEPARATED
}


foreach X of numlist 1/6 {
	generate separation`X' = .c
}

foreach X of numlist 1/6 {
	replace separation`X' = 1 if (divorced`X'==1) | (separated`X'==1)
	replace separation`X' = 0 if (divorced`X'==0) | (separated`X'==0)
}

label define SEPARATION 0 "Partnered" 1 "Divorced or separated, single" 

foreach X of varlist separation1-separation6 {
	label variable `X' "Divorced or Separated "
	label values `X' SEPARATION
}


* Transition of divorce or separation

foreach X of numlist 2/6 {
	generate divorce`X' = .c	
}

* wave 1 to wave 2
replace divorce2 = 0 if (separation1==0) & (separation2==0) 
replace divorce2 = 0 if (separation1==1) & (separation2==0) 
replace divorce2 = 0 if (separation1==1) & (separation2==1) 
replace divorce2 = 1 if (separation1==0) & (separation2==1) 

* wave 2 to wave 3
replace divorce3 = 0 if (separation2==0) & (separation3==0) 
replace divorce3 = 0 if (separation2==1) & (separation3==0) 
replace divorce3 = 0 if (separation2==1) & (separation3==1) 
replace divorce3 = 1 if (separation2==0) & (separation3==1) 

* wave 3 to wave 4
replace divorce4 = 0 if (separation3==0) & (separation4==0) 
replace divorce4 = 0 if (separation3==1) & (separation4==0) 
replace divorce4 = 0 if (separation3==1) & (separation4==1) 
replace divorce4 = 1 if (separation3==0) & (separation4==1) 

* wave 4 to wave 5
replace divorce5 = 0 if (separation4==0) & (separation5==0) 
replace divorce5 = 0 if (separation4==1) & (separation5==0) 
replace divorce5 = 0 if (separation4==1) & (separation5==1) 
replace divorce5 = 1 if (separation4==0) & (separation5==1) 

* wave 5 to wave 6
replace divorce6 = 0 if (separation5==0) & (separation6==0) 
replace divorce6 = 0 if (separation5==1) & (separation6==0) 
replace divorce6 = 0 if (separation5==1) & (separation6==1) 
replace divorce6 = 1 if (separation5==0) & (separation6==1) 

* Summary
generate divorce = 0 
replace divorce = 1 if (divorce2==1) | (divorce3==1) | (divorce4==1) | (divorce5==1) | (divorce6==1) 

label define DIVORCE 0 "divorce does not occur" 1 "divorce occurs" 

foreach X of varlist divorce2-divorce {
	label variable `X' "Transition of divorce or separation"
	label values `X' DIVORCE
}


************************************************************************************************
*** Repartnering
* Relationship status

foreach X of numlist 1/6 {
	generate repartner`X' = .c
}

foreach X of numlist 1/6 {
	replace repartner`X' = 0 if (relationship`X'==2) | (relationship`X'==3) | (relationship`X'==4) 
	replace repartner`X' = 1 if (relationship`X'==5) | (relationship`X'==6) | (relationship`X'==7)
}

label define REPARTNER 0 "Single" 1 "Living in non-marital partnership" 

foreach X of varlist repartner1-repartner6 {
	label variable `X' "Repartner"
	label values `X' REPARTNER
}

* Transition to new partnership

foreach X of numlist 2/6 {
	generate repartnering`X' = .c	
}

* wave 1 to wave 2
replace repartnering2 = 0 if (repartner1==0) & (repartner2==0) 
replace repartnering2 = 0 if (repartner1==1) & (repartner2==0) 
replace repartnering2 = 0 if (repartner1==1) & (repartner2==1) 
replace repartnering2 = 1 if (repartner1==0) & (repartner2==1) 

* wave 2 to wave 3
replace repartnering3 = 0 if (repartner2==0) & (repartner3==0) 
replace repartnering3 = 0 if (repartner2==1) & (repartner3==0) 
replace repartnering3 = 0 if (repartner2==1) & (repartner3==1) 
replace repartnering3 = 1 if (repartner2==0) & (repartner3==1) 

* wave 3 to wave 4
replace repartnering4 = 0 if (repartner3==0) & (repartner4==0) 
replace repartnering4 = 0 if (repartner3==1) & (repartner4==0) 
replace repartnering4 = 0 if (repartner3==1) & (repartner4==1) 
replace repartnering4 = 1 if (repartner3==0) & (repartner4==1) 

* wave 4 to wave 5
replace repartnering5 = 0 if (repartner4==0) & (repartner5==0) 
replace repartnering5 = 0 if (repartner4==1) & (repartner5==0) 
replace repartnering5 = 0 if (repartner4==1) & (repartner5==1) 
replace repartnering5 = 1 if (repartner4==0) & (repartner5==1) 

* wave 5 to wave 6
replace repartnering6 = 0 if (repartner5==0) & (repartner6==0) 
replace repartnering6 = 0 if (repartner5==1) & (repartner6==0) 
replace repartnering6 = 0 if (repartner5==1) & (repartner6==1) 
replace repartnering6 = 1 if (repartner5==0) & (repartner6==1) 

* Summary
generate repartnering = 0 
replace repartnering = 1 if (repartnering2==1) | (repartnering3==1) | (repartnering4==1) | (repartnering5==1) | (repartnering6==1) 

label define repartnering 0 "repartnering does not occur" 1 "repartnering occurs" 

foreach X of varlist repartnering2-repartnering {
	label variable `X' "Transition to new partnership"
	label values `X' repartnering
}

recode repartner1-repartner6 (.c=0)

************************************************************************************************
*** Sampling: Analysis sample
/// Keeping respondents who are constantly partnered, constantly single, or experience widowhood, divorce/separation or repartnering 

tab marriage
tab partner
tab constantwid
tab single
tab widowhood
tab divorce
tab repartnering

keep if (partner==1) | (single==1) | (widowhood==1) | (divorce==1) | (repartnering==1)

* The following code was used to create Table 2a
tab grandparents 
sum pa freedom needs adaption cognitive dependency vitality serenity health network age n_obs 

/// Keeping infromation on which respondents are in the analysis sample 
keep fallnum partner single marriage constantwid widowhood divorce repartnering

save descriptive_analysis_sample.dta, replace

************************************************************************************************
*** Merging the baseline and analysis data
use Baseline_crosssectional_JFR.dta, clear

* Adding the analysis data set 
merge 1:1 fallnum using descriptive_analysis_sample.dta

************************************************************************************************
*** Description of the analysis sample 

keep if (partner==1) | (single==1) | (widowhood==1) | (divorce==1) | (repartnering==1)

* The following code was used to create Table 2a & Table A.1a
tab1 relationship gender education migrat grandparents
sum pa freedom needs adaption cognitive dependency vitality serenity age health network ageWID ageDIV ageRP n_obs

* The following code was used to create Table 2a
foreach X of varlist partner single marriage constantwid widowhood divorce repartnering {
	tab1 relationship gender education migrat grandparents if `X'==1
	sum pa freedom needs adaption cognitive dependency vitality serenity age health network ageWID ageDIV ageRP n_obs if `X'==1
}


exit

