********************************************************************************
********************************************************************************
*Do partnership transitions affect the individual perception of aging in later life? Findings from the German Ageing Survey and the NRW80+ study
*Journal of Family Research, 2023
*Title: 07_JFR_Analysis_Widowhood_NRW80+
*Author: Stefan Mauritz
*Data set: NRW80+ panel data (ZA7893_v1-0-0), doi: 10.4232/1.13985
********************************************************************************
********************************************************************************

clear all
capture log close
version 17.0
set more off

*Directories
global inpath 	//	directory of original data
global outpath 	//  working directory
cd $inpath


********************************************************************************
*****************************DATA TRANSFORMATION********************************
********************************************************************************

use preparation_NRW80, clear

*Long format
reshape long freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W widowed_W genderwid_W age_W health_W grandparents_W network_W, i(ID) j(wave)

label var freedom_W "Freedom"
label var needs_W "Needs"
label var adaption_W "Adaption"
label var cognitive_W "Cognitive capacity"
label var dependency_W "Dependency"
label var vitality_W "Vitality"
label var serenity_W "Serenity"
label var pa_W "Perceptions of aging (index)"
label var widowed_W "Widowhood"
label var genderwid_W "Interaction gender/widowhood"
label var age_W "Age"
label var health_W "Physical health"
label var grandparents "Grandparenthood"
label var network_W "Network size"

xtset ID wave

*Preparation for hybrid regression models
egen b_widowed_W=mean(widowed_W), by(ID)
gen w_widowed_W=widowed_W-b_widowed_W

egen b_gender_W=mean(gender_W), by(ID)

egen b_genderwid_W=mean(genderwid_W), by(ID)
gen w_genderwid_W=genderwid_W-b_genderwid_W

egen b_education_W=mean(education_W), by(ID)

egen b_migrat_W=mean(migrat_W), by(ID)

egen b_age_W=mean(age_W), by(ID)
gen w_age_W=age_W-b_age_W

egen b_health_W=mean(health_W), by(ID)
gen w_health_W=health_W-b_health_W

egen b_grandparents_W=mean(grandparents_W), by(ID)
gen w_grandparents_W=grandparents_W-b_grandparents_W

egen b_network_W=mean(network_W), by(ID)
gen w_network_W=network_W-b_network_W

save data_NRW80, replace


********************************************************************************
********************************DATA ANALYSIS***********************************
********************************************************************************

******************************SAMPLE DESCRIPTION********************************
***************the following code was used to create Table 2b*******************

use data_NRW80, clear

*Sample: Total
sum ID freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W widowed_W gender_W migrat_W age_W health_W grandparents_W network_W widowage_W if wave==1
tab education_W if wave==1

sum ID freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W widowed_W age_W health_W grandparents_W network_W

*Sample: Constantly married
sum ID freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W gender_W migrat_W age_W health_W grandparents_W network_W if conmarried_W==1 & wave==1
tab education_W if conmarried_W==1 & wave==1
sum ID if conmarried_W==1

*Sample: Constantly widowed
sum ID freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W gender_W migrat_W age_W health_W grandparents_W network_W if conwidowed_W==1 & wave==1
tab education_W if conwidowed_W==1 & wave==1
sum ID if conwidowed_W==1

*Sample: Recently widowed
sum ID freedom_W needs_W adaption_W cognitive_W dependency_W vitality_W serenity_W pa_W gender_W migrat_W age_W health_W grandparents_W network_W if recwidowed_W==1 & wave==1
tab education_W if recwidowed_W==1 & wave==1
sum ID if recwidowed_W==1


****************************HYBRID REGRESSION MODELS****************************
************the following code was used to create Table 3c & Table 3d***********

*Model a: Index PA
use data_NRW80, clear
xtset ID wave
xtreg pa_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg pa_W b_widowed_W w_widowed_W, re
outreg2 using Table_3c.xls, replace ctitle(Model 1a) dec(2)
xtreg pa_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 2a) dec(2)
xtreg pa_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3c.xls, append ctitle(Model 3a) dec(2)
xtreg pa_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3c.xls, append ctitle(Model 4a) dec(2)

*Model b: Freedom
use data_NRW80, clear
xtset ID wave
xtreg freedom_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg freedom_W b_widowed_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 1b) dec(2)
xtreg freedom_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 2b) dec(2)
xtreg freedom_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3c.xls, append ctitle(Model 3b) dec(2)
xtreg freedom_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3c.xls, append ctitle(Model 4b) dec(2)

*Model c: Needs
use data_NRW80, clear
xtset ID wave
xtreg needs_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg needs_W b_widowed_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 1c) dec(2)
xtreg needs_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 2c) dec(2)
xtreg needs_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3c.xls, append ctitle(Model 3c) dec(2)
xtreg needs_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3c.xls, append ctitle(Model 4c) dec(2)

*Model d: Adaption
use data_NRW80, clear
xtset ID wave
xtreg adaption_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg adaption_W b_widowed_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 1d) dec(2)
xtreg adaption_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3c.xls, append ctitle(Model 2d) dec(2)
xtreg adaption_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3c.xls, append ctitle(Model 3d) dec(2)
xtreg adaption_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3c.xls, append ctitle(Model 4d) dec(2)

*Model e: Cognitive capacity
use data_NRW80, clear
xtset ID wave
xtreg cognitive_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg cognitive_W b_widowed_W w_widowed_W, re
outreg2 using Table_3d.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3d.xls, append ctitle(Model 3e) dec(2)
xtreg cognitive_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3d.xls, append ctitle(Model 4e) dec(2)

*Model f: Dependency
use data_NRW80, clear
xtset ID wave
xtreg dependency_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg dependency_W b_widowed_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 1f) dec(2)
xtreg dependency_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 2f) dec(2)
xtreg dependency_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3d.xls, append ctitle(Model 3f) dec(2)
xtreg dependency_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3d.xls, append ctitle(Model 4f) dec(2)

*Model g: Vitality
use data_NRW80, clear
xtset ID wave
xtreg vitality_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg vitality_W b_widowed_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 1g) dec(2)
xtreg vitality_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 2g) dec(2)
xtreg vitality_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3d.xls, append ctitle(Model 3g) dec(2)
xtreg vitality_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3d.xls, append ctitle(Model 4g) dec(2)

*Model h: Serenity
use data_NRW80, clear
xtset ID wave
xtreg serenity_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg serenity_W b_widowed_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 1h) dec(2)
xtreg serenity_W b_widowed_W b_gender_W w_widowed_W, re
outreg2 using Table_3d.xls, append ctitle(Model 2h) dec(2)
xtreg serenity_W b_widowed_W b_gender_W b_genderwid_W w_widowed_W w_genderwid_W, re
outreg2 using Table_3d.xls, append ctitle(Model 3h) dec(2)
xtreg serenity_W b_widowed_W b_gender_W b_genderwid_W b_age_W b_education_W b_migrat_W b_health_W b_grandparents_W b_network_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, re
outreg2 using Table_3d.xls, append ctitle(Model 4h) dec(2)


*************************ROBUSTNESS CHECK: FE MODELS****************************
**********the following code was used to create Table A.3c & Table A.3d*********

*Model a: Index PA
use data_NRW80, clear
xtset ID wave
xtreg pa_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg pa_W w_widowed_W, fe
outreg2 using Table_A3c.xls, replace ctitle(Model 1a) dec(2)
xtreg pa_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 2a) dec(2)
xtreg pa_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 3a) dec(2)

*Model b: Freedom
use data_NRW80, clear
xtset ID wave
xtreg freedom_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg freedom_W w_widowed_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 1b) dec(2)
xtreg freedom_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 2b) dec(2)
xtreg freedom_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 3b) dec(2)

*Model c: Needs
use data_NRW80, clear
xtset ID wave
xtreg needs_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg needs_W w_widowed_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 1c) dec(2)
xtreg needs_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 2c) dec(2)
xtreg needs_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 3c) dec(2)

*Model d: Adaption
use data_NRW80, clear
xtset ID wave
xtreg adaption_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg adaption_W w_widowed_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 1d) dec(2)
xtreg adaption_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 2d) dec(2)
xtreg adaption_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3c.xls, append ctitle(Model 3d) dec(2)

*Model e: Cognitive capacity
use data_NRW80, clear
xtset ID wave
xtreg cognitive_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg cognitive_W w_widowed_W, fe
outreg2 using Table_A3d.xls, replace ctitle(Model 1e) dec(2)
xtreg cognitive_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 2e) dec(2)
xtreg cognitive_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 3e) dec(2)

*Model f: Dependency
use data_NRW80, clear
xtset ID wave
xtreg dependency_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg dependency_W w_widowed_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 1f) dec(2)
xtreg dependency_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 2f) dec(2)
xtreg dependency_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 3f) dec(2)

*Model g: Vitality
use data_NRW80, clear
xtset ID wave
xtreg vitality_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg vitality_W w_widowed_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 1g) dec(2)
xtreg vitality_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 2g) dec(2)
xtreg vitality_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 3g) dec(2)

*Model h: Serenity
use data_NRW80, clear
xtset ID wave
xtreg serenity_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
gen sample_var=e(sample)
tab sample_var
drop if sample_var==0

xtreg serenity_W w_widowed_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 1h) dec(2)
xtreg serenity_W w_widowed_W w_genderwid_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 2h) dec(2)
xtreg serenity_W w_widowed_W w_genderwid_W w_age_W w_health_W w_grandparents_W w_network_W, fe
outreg2 using Table_A3d.xls, append ctitle(Model 3h) dec(2)

exit
